@@ -49,4 +49,7 @@ class Glearn:
         return glearn.getCourses(self)
 
     def codeToName(self, timetable):
-        return glearn.codeToName(self, timetable)
\ No newline at end of file
+        return glearn.codeToName(self, timetable)
+    
+    def getEventsCalendar(self):
+        return glearn.getEventsCalendar(self)
\ No newline at end of file
